Motion Event Factory — Kivy v1.0.1-dev documentation

# Motion Event Factory

Factory of `MotionEvent` providers.

class `kivy.input.factory.` `MotionEventFactory`

  MotionEvent factory is a class who register all availables input factories. If you create a new input factory, don’t forget to register it

      MotionEventFactory.register('myproviderid', MyInputProvider)

  static `get`(name)

    Get a provider class from provider id

  static `list`()

    Get a list of all providers availables

  static `register`(name, classname)

    Register a input provider in the database